==> DAST-5.x-1.1.tar.gz: DAST/bin/dast.php <==
<?php
/**$Id: dast.php,v 1.1 2007/07/16 17:00:15 allisterbeharry Exp $
 * @file
 * Command line launcher for DAST
 * 
 * This is a modified version of the Phing command line launcher based on phing/bin/phing.php CVS revision 1.7. 
 * It starts up the system evironment, tests for all important paths and properties and kicks of the main command-
 * line entry point of phing located in phing.Phing
 * @author Allister Beharry
 * @package org.drupal.dast
 */

/* Check min. required PHP version */
$ver = explode( '.', PHP_VERSION );
$ver_num = $ver[0] . $ver[1] . $ver[2];
if ( $ver_num < 520 ) die ( 'This script needs PHP 5.2.0 or above!' );

/* Set any INI options for PHP */
ini_set('track_errors', 1); 

define('DAST_HOME', realpath(realpath(dirname(__FILE__)).DIRECTORY_SEPARATOR.'..'.DIRECTORY_SEPARATOR));
/** @TODO simplify arguments **/
/** @TODO Finish check for build file
for ($i = 0, $argcount = count($args); $i < $argcount; ++$i) { 
  // ++$i intentional here, as first param is script name
  $arg = $args[$i];
  if ($arg == "-buildfile" || $arg == "-file" || $arg == "-f") {
                if (!isset($args[$i+1])) {
                    $msg = "You must specify a buildfile when using the or-buildfile argument.";

            if (!file_exists(realpath($args[2]))) //3rd argument is build file 
  die("ERROR: Could not find build file $args[2].");
else {
  echo "Using build file: ".$args[2]."\n";
  $args[2] = "-f "."\"".realpath($args[2]."\"");
}
*/
 //@TODO Hook $args to check for -h and output custom help
 
/* Make sure all required libraries are present and accounted for */
echo "Using DAST_HOME: ".DAST_HOME."...\n";
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'phing'))
  echo "Phing found...\n";
else
  die ("ERROR: Phing not found at ".DAST_HOME.DIRECTORY_SEPARATOR.'phing'."- see README.txt on installing Phing for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'creole'))
  echo "Creole found...\n";
else
  die ("ERROR: Creole not found - see README.txt on installing Creole for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__); 
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'jargon'))
  echo "Jargon found...\n";
else
  die ("ERROR: Jargon not found - see README.txt on installing Jargon for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'simpletest'))
  echo "Simpletest found...\n";
else
  die ("ERROR: Simpletest not found - see README.txt on installing Simpletest for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
//@TODO Detect and allow the use of libraries installed through PEAR or anywhere on the include_path.

/* set classpath - we want to use our own versions of phing and creole and jargon and simpletest so in PHP_CLASSPATH
 * make sure the libraries bundled with dast are included first
*/
define ('DAST_CLASSPATH', DAST_HOME.DIRECTORY_SEPARATOR.'src'.PATH_SEPARATOR.DAST_HOME.DIRECTORY_SEPARATOR.'phing'.DIRECTORY_SEPARATOR.'classes'.PATH_SEPARATOR.DAST_HOME);
if (getenv('PHP_CLASSPATH')) {
    define('PHP_CLASSPATH',  
     DAST_CLASSPATH.PATH_SEPARATOR.getenv('PHP_CLASSPATH') . PATH_SEPARATOR . get_include_path());
    ini_set('include_path', PHP_CLASSPATH);
} else {
    define('PHP_CLASSPATH',  DAST_CLASSPATH.PATH_SEPARATOR.get_include_path());
    ini_set('include_path', PHP_CLASSPATH);
}
echo "Using PHP_CLASSPATH: ".PHP_CLASSPATH."\n";

require_once 'phing/Phing.php';

/* Setup Phing environment */
Phing::startup();

/* Set DAST home directory */
Phing::setProperty('dast.home', DAST_HOME);

/* Set Phing home directory */
Phing::setProperty('phing.home', DAST_HOME.DIRECTORY_SEPARATOR.'phing');

/*Set PHP DIRECTORY_SEPARATOR property - needed for any filesystem ops */
Phing::setProperty('php.directory_separator', DIRECTORY_SEPARATOR);

/* polish CLI arguments */
$args = isset($argv) ? $argv : $_SERVER['argv']; // $_SERVER['argv'] seems not to work when argv is registered (PHP5b4)
array_shift($args);

/* fire main application */
Phing::fire($args);

/*
  exit OO system if not already called by Phing
   -- basically we should not need this due to register_shutdown_function in Phing
 */
Phing::halt(0);

==> DAST-5.x-2.0.tar.gz: DAST/bin/dast.php <==
<?php
/**$Id: dast.php,v 1.4 2007/09/14 21:43:37 allisterbeharry Exp $
 * @file
 * Command line launcher for DAST
 * 
 * This is a modified version of the Phing command line launcher based on phing/bin/phing.php CVS revision 1.7. 
 * It starts up the system evironment, tests for all important paths and properties and kicks of the main command-
 * line entry point of phing located in phing.Phing
 * @author Allister Beharry
 * @package org.drupal.dast
 */

/* Check OS */
if ( substr_count(php_uname(), 'Windows') > 0 ) {
  if ( substr_count(php_uname(), 'Windows NT') <= 0 ) {
    die ("ERROR: This script requires Windows NT. \n" . " File: " . __FILE__ . " on line: " . __LINE__);
  }
} 

/* Check min. required PHP version */
$ver = explode( '.', PHP_VERSION );
$ver_num = $ver[0] . $ver[1] . $ver[2];
if ( $ver_num < 520 ) die ('ERROR: This script needs PHP 5.2.0 or above!' );

/* Set any INI options for PHP */
ini_set('track_errors', 1); 

define('DAST_HOME', realpath(realpath(dirname(__FILE__)).DIRECTORY_SEPARATOR.'..'.DIRECTORY_SEPARATOR));
define('DAST_TEST', DAST_HOME.DIRECTORY_SEPARATOR.'src'.DIRECTORY_SEPARATOR.'tests');
define('DAST_TEMP', DAST_HOME.DIRECTORY_SEPARATOR.'tmp');
define('PHING_TEST_BASE', DAST_HOME.DIRECTORY_SEPARATOR.'src');

/** @TODO simplify arguments **/
/** @TODO Finish check for build file
for ($i = 0, $argcount = count($args); $i < $argcount; ++$i) { 
  // ++$i intentional here, as first param is script name
  $arg = $args[$i];
  if ($arg == "-buildfile" || $arg == "-file" || $arg == "-f") {
                if (!isset($args[$i+1])) {
                    $msg = "You must specify a buildfile when using the or-buildfile argument.";

            if (!file_exists(realpath($args[2]))) //3rd argument is build file 
  die("ERROR: Could not find build file $args[2].");
else {
  echo "Using build file: ".$args[2]."\n";
  $args[2] = "-f "."\"".realpath($args[2]."\"");
}
*/
 //@TODO Hook $args to check for -h and output custom help

echo PHP_EOL; 
/* Make sure all required libraries are present and accounted for */
echo "Using DAST_HOME: ".DAST_HOME."...\n";
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'phing'))
  echo "Phing found...\n";
else
  die ("ERROR: Phing not found at ".DAST_HOME.DIRECTORY_SEPARATOR.'phing'."- see README.txt on installing Phing for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'creole'))
  echo "Creole found...\n";
else
  die ("ERROR: Creole not found - see README.txt on installing Creole for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__); 
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'jargon'))
  echo "Jargon found...\n";
else
  die ("ERROR: Jargon not found - see README.txt on installing Jargon for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'simpletest'))
  echo "Simpletest found...\n";
else
  die ("ERROR: Simpletest not found - see README.txt on installing Simpletest for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
if (file_exists(DAST_HOME.DIRECTORY_SEPARATOR.'PEAR_Config'))
  echo "PEAR::Config (bundled) found...\n";
else
  die ("ERROR: PEAR::Config not found - see README.txt on installing PEAR::Config for DAST.\n" . " File: " . __FILE__ . " on line: " . __LINE__);
echo PHP_EOL;
//@TODO Detect and allow the use of libraries installed through PEAR or anywhere on the include_path.

/* set classpath - we want to use our own versions of phing and creole and jargon and simpletest so in PHP_CLASSPATH
 * make sure the libraries bundled with dast are included first
*/
define ('DAST_CLASSPATH', DAST_HOME.PATH_SEPARATOR.DAST_HOME.DIRECTORY_SEPARATOR.'src'.PATH_SEPARATOR.DAST_HOME.DIRECTORY_SEPARATOR.'phing'.
         DIRECTORY_SEPARATOR.'classes'.PATH_SEPARATOR.DAST_HOME.DIRECTORY_SEPARATOR.'PHPUnit');

if (getenv('PHP_CLASSPATH')) {
    define('PHP_CLASSPATH',  
     DAST_CLASSPATH.PATH_SEPARATOR.getenv('PHP_CLASSPATH') . PATH_SEPARATOR . get_include_path());
    ini_set('include_path', PHP_CLASSPATH);
} else {
    define('PHP_CLASSPATH',  DAST_CLASSPATH.PATH_SEPARATOR.get_include_path());
    ini_set('include_path', PHP_CLASSPATH);
}

echo "Using PHP_CLASSPATH: ".PHP_CLASSPATH."\n";
echo PHP_EOL;
require_once 'phing/Phing.php';

/* Setup Phing environment */
Phing::startup();

/* Set DAST home directory */
Phing::setProperty('dast.home', DAST_HOME);

/* Set Phing home directory */
Phing::setProperty('phing.home', DAST_HOME.DIRECTORY_SEPARATOR.'phing');

/* Set DAST tmp directory */
Phing::setProperty('dast.tmp', DAST_HOME.DIRECTORY_SEPARATOR.'tmp');

/* Set DAST ext directory */
Phing::setProperty('dast.ext', DAST_HOME.DIRECTORY_SEPARATOR.'ext');

/*Set PHP DIRECTORY_SEPARATOR property - needed for any filesystem ops */
Phing::setProperty('php.directory_separator', DIRECTORY_SEPARATOR);
Phing::setProperty('php.path_separator', PATH_SEPARATOR);

/* polish CLI arguments */
$args = isset($argv) ? $argv : $_SERVER['argv']; // $_SERVER['argv'] seems not to work when argv is registered (PHP5b4)
array_shift($args);

/* fire main application */
Phing::fire($args);

/*
  exit OO system if not already called by Phing
   -- basically we should not need this due to register_shutdown_function in Phing
 */
Phing::halt(0);
